@@ -20,17 +20,22 @@
 #ifndef BOMBER_WIDGET_H
 #define BOMBER_WIDGET_H
 
-#include "board.h"
-
+// Qt
 #include <QGraphicsView>
 #include <QMouseEvent>
 
+// KDE
+#include <KgSound>
+
+// Bomber
+#include "board.h"
+
 class KgThemeProvider;
 
 /**
  * This is the main game widget class. It manages things like the lives, source counts and game states.
  */
-class BomberGameWidget: public QGraphicsView
+class BomberGameWidget : public QGraphicsView
 {
     Q_OBJECT
 
@@ -38,10 +43,14 @@ public:
     /**
      * The different states that the game can be in
      */
-    enum class State
-    {   BeforeFirstGame, Running, BetweenLevels, Paused, Suspended, GameOver};
+    enum class State { BeforeFirstGame,
+                       Running,
+                       BetweenLevels,
+                       Paused,
+                       Suspended,
+                       GameOver };
 
-    explicit BomberGameWidget(KgThemeProvider *provider, QWidget *parent = nullptr);
+    explicit BomberGameWidget(KgThemeProvider * provider, QWidget * parent = nullptr);
     ~BomberGameWidget();
 
     /**
@@ -86,9 +95,9 @@ public slots:
 
     /**
      * Enabled or disabled the sounds
-     * \param value True to enable the sounds, otherwise false
+     * \param enable True to enable the sounds, false to disable
      */
-    void setSounds(bool value);
+    void setSoundsEnabled(bool enable);
 
     /**
      * Used to toggle the suspended game state. If val is true and the state is currently running,
@@ -160,8 +169,8 @@ private slots:
     void onPlaneCrashed();
 
 private:
-    virtual void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
-    virtual void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+    virtual void resizeEvent(QResizeEvent * event) Q_DECL_OVERRIDE;
+    virtual void mouseReleaseEvent(QMouseEvent * event) Q_DECL_OVERRIDE;
 
     /**
      * Create the overlay used to display info to the user. The info will
@@ -173,21 +182,28 @@ private:
     void closeLevel();
     void newLevel();
 
+    void playBombSound();
+    void playCrashSound();
+
     State m_state;
     unsigned int m_level;
     unsigned int m_score;
     unsigned int m_lives;
     unsigned int m_time;
+
     /**
      * Used to store the remaining score before a new life is given
      */
     int m_scoreLeftBeforeNewLife;
 
     KGameRenderer m_renderer;
-    QTimer *m_clock;
-    BomberBoard *m_board;
+    QTimer * m_clock;
+    BomberBoard * m_board;
 
-    QGraphicsPixmapItem *m_overlay;
+    QGraphicsPixmapItem * m_overlay;
+
+    KgSound m_soundBomb;
+    KgSound m_soundCrash;
 };
 
 #endif
