@@ -16,12 +16,15 @@
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+// own
 #include "explodable.h"
 
-#include "board.h"
-
+// KDE
 #include <KRandom>
 
+// Bomber
+#include "board.h"
+
 /**
  * How big is the explosion in relation to the tiles height.
  * 1.0 means it's the same size as the tile.
@@ -33,11 +36,13 @@ const qreal Explodable::EXPLOSION_RELATIVE_SIZE_H = 1.0;
  */
 const qreal Explodable::EXPLOSION_RELATIVE_SIZE_W = 1.0;
 
-Explodable::Explodable(const QString &mainSvg, const QString &explosionSvg,
-                       qreal relativeWidth, qreal relativeHeight, KGameRenderer *renderer,
-                       BomberBoard *board) :
-    KGameRenderedItem(renderer, mainSvg), m_board(board), m_mainSvg(
-        mainSvg), m_explosionSvg(explosionSvg)
+Explodable::Explodable(const QString & mainSvg, const QString & explosionSvg,
+                       qreal relativeWidth, qreal relativeHeight, KGameRenderer * renderer,
+                       BomberBoard * board)
+    : KGameRenderedItem(renderer, mainSvg)
+    , m_board(board)
+    , m_mainSvg(mainSvg)
+    , m_explosionSvg(explosionSvg)
 {
     setRenderSize(QSize(32, 64));
     m_relativeWidth = relativeWidth;
@@ -64,19 +69,17 @@ void Explodable::update()
     setPos(m_board->mapPosition(QPointF(m_xPos, m_yPos)));
 }
 
-void Explodable::resize(const QSize &tileSize)
+void Explodable::resize(const QSize & tileSize)
 {
     m_lastSize = tileSize;
     if (m_state == State::Moving) {
         setRenderSize(QSize(
-                          m_relativeWidth * tileSize.width(),
-                          m_relativeHeight * tileSize.height()
-                      ));
+            m_relativeWidth * tileSize.width(),
+            m_relativeHeight * tileSize.height()));
     } else {
         setRenderSize(QSize(
-                          EXPLOSION_RELATIVE_SIZE_W * tileSize.width(),
-                          EXPLOSION_RELATIVE_SIZE_H * tileSize.height()
-                      ));
+            EXPLOSION_RELATIVE_SIZE_W * tileSize.width(),
+            EXPLOSION_RELATIVE_SIZE_H * tileSize.height()));
     }
     setPos(m_board->mapPosition(QPointF(m_xPos, m_yPos)));
 }
