@@ -15,22 +15,26 @@
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
-#include "bomber.h"
 
-#include <KAboutData>
-#include <KCrash>
-
-#include <KLocalizedString>
+// Qt
 #include <QApplication>
 #include <QCommandLineParser>
-#include <kdelibs4configmigrator.h>
+
+// KDE
+#include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
+#include <KLocalizedString>
+#include <Kdelibs4ConfigMigrator>
+
+// Bomber
+#include "bomber.h"
 
 static const char description[] = I18N_NOOP("Arcade bombing game");
 
-static const char version[] = "0.3";
+static const char version[] = "0.4";
 
-int main(int argc, char **argv)
+int main(int argc, char ** argv)
 {
     QApplication app(argc, argv);
     Kdelibs4ConfigMigrator migrate(QStringLiteral("bomber"));
