@@ -15,8 +15,11 @@
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
+
+// own
 #include "plane.h"
 
+// Bomber
 #include "board.h"
 #include "explodable.h"
 
@@ -29,9 +32,9 @@ const qreal Plane::PLANE_RELATIVE_SIZE = 1;
 /** This is the position before the plane goes off the screen */
 const qreal Plane::PLANE_MAX_POSITION_X = 12;
 
-Plane::Plane(KGameRenderer *renderer, BomberBoard *board) :
-    Explodable(QLatin1Literal("plane"), QLatin1Literal("plane_explode"), PLANE_RELATIVE_SIZE,
-               PLANE_RELATIVE_SIZE, renderer, board)
+Plane::Plane(KGameRenderer * renderer, BomberBoard * board)
+    : Explodable(QLatin1Literal("plane"), QLatin1Literal("plane_explode"), PLANE_RELATIVE_SIZE,
+                 PLANE_RELATIVE_SIZE, renderer, board)
 {
     setVelocity(DEFAULT_VELOCITY);
     resetPosition();
